# Tools

Types:

```python
from labric.types import ToolReadResponse, ToolWriteResponse
```

Methods:

- <code title="post /api/v1/tools/read">client.tools.<a href="./src/labric/resources/tools.py">read</a>(\*\*<a href="src/labric/types/tool_read_params.py">params</a>) -> <a href="./src/labric/types/tool_read_response.py">ToolReadResponse</a></code>
- <code title="post /api/v1/tools/write">client.tools.<a href="./src/labric/resources/tools.py">write</a>(\*\*<a href="src/labric/types/tool_write_params.py">params</a>) -> <a href="./src/labric/types/tool_write_response.py">ToolWriteResponse</a></code>
